@@ -16,7 +16,6 @@
 .. module:: stardata
 """
 
-from __future__ import print_function
 import numpy as np
 import copy
 import galsim
@@ -163,7 +162,7 @@ class Star(object):
     def run_hsm(self):
         """Use HSM to measure moments of star image.
 
-        This usually isn't called directly.  The results (without flag) are accessible as star.hsm,
+        This usually isn't called directly.  The results are accessible as star.hsm,
         which caches the results, so repeated access is efficient.
 
         :returns: (flux, cenu, cenv, size, g1, g2, flag)
@@ -492,24 +491,35 @@ class Star(object):
         from .input import InputFiles
 
         logger = galsim.config.LoggerWrapper(logger)
+
+        logger.error("WARNING: The Star.load_images function is deprecated."
+                     "Use InputFiles.load_images instead.")
+
         logger.info("Loading image information from file %s",file_name)
+        config = {
+            'image_file_name': file_name,
+            'cat_file_name': None,  # We don't need this, but it needs to be present.
+            'image_hdu': image_hdu,
+            'weight_hdu': weight_hdu,
+            'badpix_hdu': badpix_hdu,
+            'noise': noise,
+        }
 
-        image, weight = InputFiles.readImage(file_name, image_hdu, weight_hdu, badpix_hdu,
-                                             noise=noise, logger=logger)
-        if sky:
-            image -= sky
-
-        stars = [ Star(data = StarData(image=image[star.data.image.bounds].copy(),
-                                       image_pos=star.data.image_pos,
-                                       weight=weight[star.data.image.bounds].copy(),
-                                       pointing= (pointing if pointing is not None
-                                                  else star.data.pointing),
-                                       properties=star.data.properties,
-                                       _xyuv_set=True),
-                       fit = star.fit)
-                  for star in stars ]
-        return stars
+        if sky is not None:
+            # This should have been set in the star.data.properties already, but in the old
+            # API, it was allowed to set a value for sky that was not already in the stars.
+            # So set the sky property in each star here.
+            stars = [Star(StarData(image=s.data.image,
+                                   image_pos=s.data.image_pos,
+                                   weight=s.data.weight,
+                                   orig_weight=s.data.orig_weight,
+                                   pointing=s.data.pointing,
+                                   properties=dict(s.data.properties, sky=sky),
+                                   _xyuv_set = True),
+                          s.fit) for s in stars]
 
+        input_files = InputFiles(config, logger=logger)
+        return input_files.load_images(stars)
 
     def offset_to_center(self, offset):
         """A utility routine to convert from an offset in image coordinates to the corresponding
@@ -637,6 +647,7 @@ class StarData(object):
         self.image_pos = image_pos
         # Make sure we have a local wcs in case the provided image is more complex.
         self.local_wcs = image.wcs.local(image_pos)
+        self.pixel_area = self.local_wcs.pixelArea()
 
         if weight is None:
             self.weight = galsim.Image(image.bounds, init_value=1, wcs=image.wcs, dtype=float)
@@ -729,21 +740,17 @@ class StarData(object):
         """
         return self.image, self.weight, self.image_pos
 
-    def getDataVector(self, include_zero_weight=False):
+    def getDataVector(self):
         """Get the pixel data as a numpy array.
 
         Also returns the weight values and the local u,v coordinates of the pixels.
         Any pixels with zero weight (e.g. from masking in the original image) will not be
         included in the returned arrays.
 
-        :param include_zero_weight: Should points with zero weight be included? [default: False]
-
         :returns: data_vector, weight_vector, u_vector, v_vector
         """
-        nx = self.image.bounds.xmax - self.image.bounds.xmin + 1
-        ny = self.image.bounds.ymax - self.image.bounds.ymin + 1
-        # Alternatively, this also works.  Just need to remember that numpy arrays use y,x indexing.
-        #ny, nx = self.image.array.shape
+        # Remember that numpy arrays use y,x indexing.
+        ny, nx = self.image.array.shape
 
         # Image coordinates of pixels relative to nominal center
         xvals = np.arange(self.image.bounds.xmin, self.image.bounds.xmax+1, dtype=float)
@@ -761,13 +768,7 @@ class StarData(object):
         v = v.flatten()
         pix = self.image.array.flatten()
         wt = self.weight.array.flatten()
-
-        # Which pixels do we want to return?
-        if include_zero_weight:
-            return pix, wt, u, v
-        else:
-            mask = wt != 0.
-            return pix[mask], wt[mask], u[mask], v[mask]
+        return pix, wt, u, v
 
     def addPoisson(self, signal=None, gain=None):
         """Return new StarData with the weight values altered to reflect
