@@ -18,7 +18,6 @@
 
 """
 
-from __future__ import print_function
 import numpy as np
 import os
 import warnings
@@ -158,15 +157,23 @@ class Stats(object):
         for star, shape in zip(stars, shapes_truth):
             logger.debug("real shape for star at %s is %s",star.image_pos, shape)
 
+        # If no stars, then shapes_truth is the wrong shape.  This line is normally a no op
+        # but makes things work right if len(stars)=0.
+        shapes_truth = shapes_truth.reshape((len(stars),7))
+
         # Pull out the positions to return
         positions = np.array([ (star.data.properties['u'], star.data.properties['v'])
                                for star in stars ])
 
         # generate the model stars and measure moments
-        logger.debug("Generating and Measuring Model Stars")
-        shapes_model = np.array([ star.hsm for star in psf.drawStarList(stars)])
-        for star, shape in zip(stars, shapes_model):
-            logger.debug("model shape for star at %s is %s",star.image_pos, shape)
+        if psf is None:
+            shapes_model = None
+        else:
+            logger.debug("Generating and Measuring Model Stars")
+            shapes_model = np.array([ star.hsm for star in psf.drawStarList(stars)])
+            shapes_model = shapes_model.reshape((len(stars),7))
+            for star, shape in zip(stars, shapes_model):
+                logger.debug("model shape for star at %s is %s",star.image_pos, shape)
 
         return positions, shapes_truth, shapes_model
 
@@ -285,8 +292,8 @@ class ShapeHistStats(Stats):
         all_T = np.concatenate([self.T_model, self.T])
         logger.info("nbins = %s",nbins)
         logger.info("cut_frac = %s",self.cut_frac)
-        rng = (np.quantile(all_T, self.cut_frac, interpolation='higher'),
-               np.quantile(all_T, 1-self.cut_frac, interpolation='lower'))
+        rng = (np.quantile(all_T, self.cut_frac, interpolation='lower'),
+               np.quantile(all_T, 1-self.cut_frac, interpolation='higher'))
         logger.info("T_d: Full range = (%f, %f)",np.min(self.T),np.max(self.T))
         logger.info("T_m: Full range = (%f, %f)",np.min(self.T_model),np.max(self.T_model))
         logger.info("Display range = (%f, %f)",rng[0],rng[1])
@@ -294,8 +301,8 @@ class ShapeHistStats(Stats):
         ax.legend(loc='upper right')
         # axs[0,1] = size difference
         ax = axs[1, 0]
-        rng = (np.quantile(self.dT, self.cut_frac, interpolation='higher'),
-               np.quantile(self.dT, 1-self.cut_frac, interpolation='lower'))
+        rng = (np.quantile(self.dT, self.cut_frac, interpolation='lower'),
+               np.quantile(self.dT, 1-self.cut_frac, interpolation='higher'))
         logger.info("dT: Full range = (%f, %f)",np.min(self.dT),np.max(self.dT))
         logger.info("Display range = (%f, %f)",rng[0],rng[1])
         ax.hist(self.dT, bins=nbins, range=rng, **kwargs)
@@ -303,8 +310,8 @@ class ShapeHistStats(Stats):
         # axs[1,0] = g1 distribution
         ax = axs[0, 1]
         all_g1 = np.concatenate([self.g1_model, self.g1])
-        rng = (np.quantile(all_g1, self.cut_frac, interpolation='higher'),
-               np.quantile(all_g1, 1-self.cut_frac, interpolation='lower'))
+        rng = (np.quantile(all_g1, self.cut_frac, interpolation='lower'),
+               np.quantile(all_g1, 1-self.cut_frac, interpolation='higher'))
         logger.info("g1_d: Full range = (%f, %f)",np.min(self.g1),np.max(self.g1))
         logger.info("g1_m: Full range = (%f, %f)",np.min(self.g1_model),np.max(self.g1_model))
         logger.info("Display range = (%f, %f)",rng[0],rng[1])
@@ -312,8 +319,8 @@ class ShapeHistStats(Stats):
         ax.legend(loc='upper right')
         # axs[1,0] = g1 difference
         ax = axs[1, 1]
-        rng = (np.quantile(self.dg1, self.cut_frac, interpolation='higher'),
-               np.quantile(self.dg1, 1-self.cut_frac, interpolation='lower'))
+        rng = (np.quantile(self.dg1, self.cut_frac, interpolation='lower'),
+               np.quantile(self.dg1, 1-self.cut_frac, interpolation='higher'))
         logger.info("dg1: Full range = (%f, %f)",np.min(self.dg1),np.max(self.dg1))
         logger.info("Display range = (%f, %f)",rng[0],rng[1])
         ax.hist(self.dg1, bins=nbins, range=rng, **kwargs)
@@ -321,8 +328,8 @@ class ShapeHistStats(Stats):
         # axs[2,0] = g2 distribution
         ax = axs[0, 2]
         all_g2 = np.concatenate([self.g2_model, self.g2])
-        rng = (np.quantile(all_g2, self.cut_frac, interpolation='higher'),
-               np.quantile(all_g2, 1-self.cut_frac, interpolation='lower'))
+        rng = (np.quantile(all_g2, self.cut_frac, interpolation='lower'),
+               np.quantile(all_g2, 1-self.cut_frac, interpolation='higher'))
         logger.info("g2_d: Full range = (%f, %f)",np.min(self.g2),np.max(self.g2))
         logger.info("g2_m: Full range = (%f, %f)",np.min(self.g2_model),np.max(self.g2_model))
         logger.info("Display range = (%f, %f)",rng[0],rng[1])
@@ -330,8 +337,8 @@ class ShapeHistStats(Stats):
         ax.legend(loc='upper right')
         # axs[2,0] = g2 difference
         ax = axs[1, 2]
-        rng = (np.quantile(self.dg2, self.cut_frac, interpolation='higher'),
-               np.quantile(self.dg2, 1-self.cut_frac, interpolation='lower'))
+        rng = (np.quantile(self.dg2, self.cut_frac, interpolation='lower'),
+               np.quantile(self.dg2, 1-self.cut_frac, interpolation='higher'))
         logger.info("dg2: Full range = (%f, %f)",np.min(self.dg2),np.max(self.dg2))
         logger.info("Display range = (%f, %f)",rng[0],rng[1])
         ax.hist(self.dg2, bins=nbins, range=rng, **kwargs)
@@ -474,8 +481,8 @@ class RhoStats(Stats):
 
             # put in some labels
             # set the scale
-            ax.set_xscale("log", nonposx='clip')
-            ax.set_yscale("log", nonposy='clip')
+            ax.set_xscale("log", nonpositive='clip')
+            ax.set_yscale("log", nonpositive='clip')
             for rho, color, label in zip(rho_list, color_list, label_list):
                 r = np.exp(rho.logr)
                 xi = rho.xip
@@ -534,13 +541,13 @@ class RhoStats(Stats):
         axs[0].set_xlabel(r'$\theta$ (arcmin)')
         axs[0].set_ylabel(r'$\rho(\theta)$')
         axs[0].set_xscale('log')
-        axs[0].set_yscale('log', nonposy='clip')
+        axs[0].set_yscale('log', nonpositive='clip')
 
         axs[1].set_xlim(self.tckwargs['min_sep'], self.tckwargs['max_sep'])
         axs[1].set_xlabel(r'$\theta$ (arcmin)')
         axs[1].set_ylabel(r'$\rho(\theta)$')
         axs[1].set_xscale('log')
-        axs[1].set_yscale('log', nonposy='clip')
+        axs[1].set_yscale('log', nonpositive='clip')
 
         if self.skip:
             # If we're skipping the plot, the auto ymax doesn't work well (it uses 1.0),
