@@ -181,6 +181,8 @@ def check_gp(stars_training, stars_validation, kernel, optimizer,
                            nbins=nbins, min_sep=min_sep, max_sep=max_sep,
                            logger=None)
 
+    assert interp.property_names == ('u', 'v')
+
     interp.initialize(stars_training)
     interp.solve(stars=stars_training, logger=None)
 
@@ -200,7 +202,7 @@ def check_gp(stars_training, stars_validation, kernel, optimizer,
 
     np.testing.assert_allclose(y_test, y_validation, atol=atol)
 
-    if optimizer is not 'none':
+    if optimizer != 'none':
         truth_hyperparameters = np.exp(interp._init_theta)
         fitted_hyperparameters = np.exp(
                 np.array([gp._optimizer._kernel.theta for gp in interp.gps]))
@@ -434,8 +436,8 @@ def test_yaml():
 
     piff.piffify(config, logger)
     psf = piff.read(psf_file)
-    assert type(psf.model) is piff.GSObjectModel
-    assert type(psf.interp) is piff.GPInterp
+    assert type(psf.model) == piff.GSObjectModel
+    assert type(psf.interp) == piff.GPInterp
     print('nstars = ',len(psf.stars))
     target = psf.stars[17]
     test_star = psf.interp.interpolate(target)
