@@ -614,6 +614,8 @@ def test_hsmcatalog():
             'image_file_name' : image_file,
             'cat_file_name' : cat_file,
             'stamp_size' : 48,
+        },
+        'select' : {
             'reserve_frac' : 0.2,
             'seed' : 123
         },
@@ -674,6 +676,7 @@ def test_hsmcatalog():
     # Use class directly, rather than through config.
     psf = piff.PSF.read(psf_file)
     stars, _, _ = piff.Input.process(config['input'])
+    stars = piff.Select.process(config['select'], stars)
     hsmcat = piff.stats.HSMCatalogStats()
     with np.testing.assert_raises(RuntimeError):
         hsmcat.write('dummy')  # Cannot write before compute
@@ -762,8 +765,8 @@ def test_bad_hsm():
             'interp' : { 'type' : 'Mean' },
             'outliers' : {
                 'type' : 'Chisq',
-                'nsigma' : 1.e-3,  # This will throw out all but 1, which adds an additional
-                                   # test of Star stats when nstars < nplot
+                'nsigma' : 0.05   # This will throw out all but 1, which adds an additional
+                                  # test of Star stats when nstars < nplot
             }
         },
     }
@@ -779,6 +782,13 @@ def test_bad_hsm():
 
     piff.piffify(config, logger=logger)
 
+    # Confirm that all but one star was rejected, since that was part of the intent of this test.
+    psf = piff.read(psf_file)
+    print('stars = ',psf.stars)
+    print('nremoved = ',psf.nremoved)
+    assert len(psf.stars) == 1
+    assert psf.nremoved == 7    # There were 8 to start.
+
     for f in [twodhist_file, rho_file, shape_file, star_file, hsm_file]:
         assert os.path.exists(f)
 
